WritingGuidelinesStyle class

拼音格子样式配置

Annotations

Constructors

WritingGuidelinesStyle({required double fontSize, Color lineColor = const Color(0xFFE0E0E0), double lineWidth = 1.0, double baselineRatio = 2 / 3, double heightRatio = 1.5, Color? backgroundColor, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 4.0), VoidCallback? onTap})
创建写字格的样式配置。
const

Properties

backgroundColor Color?
背景色
final
baselineRatio double
基线位置占格子高度的比例
final
fontSize double
字体大小
final
hashCode int
The hash code for this object.
no setterinherited
heightRatio double
格子高度相对于字体大小的倍数
final
lineColor Color
四线三格线条颜色
final
lineWidth double
线条粗细
final
onTap VoidCallback?
点击回调
final
padding EdgeInsetsGeometry
内边距
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? fontSize, Color? lineColor, double? lineWidth, double? baselineRatio, double? heightRatio, Color? backgroundColor, EdgeInsetsGeometry? padding, VoidCallback? onTap}) WritingGuidelinesStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited