WritingGuidelinesWrap class
拼音流式布局
支持任意Widget的自动换行,自动识别每行最后一个item
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- WritingGuidelinesWrap
Constructors
-
WritingGuidelinesWrap({Key? key, required List<
Widget> children, double fontSize = 30, Color lineColor = const Color(0xFFE0E0E0), double lineWidth = 1.0, double runSpacing = 16.0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 4.0), Color? backgroundColor, VoidCallback? onTap}) -
创建会按宽度自动换行的写字格流式布局。
const
Properties
- backgroundColor → Color?
-
final
-
children
→ List<
Widget> -
final
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineColor → Color
-
final
- lineWidth → double
-
final
- onTap → VoidCallback?
-
final
- padding → EdgeInsetsGeometry
-
final
- runSpacing → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited